@@ -54,7 +54,7 @@ def experiment_variable_search(pointers,project_drs,search_path,file_type_list,o
         try:
             file_list_found=ctx.search(variable=var_name)
         except:
-            warnings.warn('Search path {0} is unresponsive at the moment'.format(search_path))
+            warnings.warn('Search path {0} is unresponsive at the moment'.format(search_path),UserWarning)
             file_list_found=[]
         file_list_remote=map(lambda x: get_urls(project_drs,x,file_type_list,var_name),file_list_found)
         file_list_remote=[item for sublist in file_list_remote for item in sublist]
