@@ -13,7 +13,7 @@ class DRS:
         #self.simulations_desc=['domain','institute','model','ensemble']
         self.simulations_desc=['institute','model','ensemble']
 
-        self.header_desc=['search_list','file_type_list','months_list','domain_list','experiment_list','variable_list']
+        self.header_desc=['search_list','file_type_list','months_list','data_node_list','experiment_list','variable_list']
 
         self.official_drs=[
               'domain',
@@ -73,7 +73,7 @@ class DRS:
 
         self.official_drs=['institute','model','experiment','time_frequency','realm','cmor_table','ensemble','version','var']
 
-        self.header_desc=['search_list','file_type_list','months_list','domain_list','experiment_list','variable_list']
+        self.header_desc=['search_list','file_type_list','months_list','data_node_list','experiment_list','variable_list']
         self.base_drs=self.official_drs+[
                   'search',
                   'file_type',
